Package: ctc
Version: 1.86.0
Date: 2005-11-16
Depends: amap
Title: Cluster and Tree Conversion.
Author: Antoine Lucas <antoinelucas@gmail.com>, Laurent Gautier <laurent@cbs.dtu.dk>
biocViews: Microarray, Clustering, Classification, DataImport,
        Visualization
Maintainer: Antoine Lucas <antoinelucas@gmail.com>
Description: Tools for export and import classification trees and clusters to other programs
License: GPL-2
URL: http://antoinelucas.free.fr/ctc
git_url: https://git.bioconductor.org/packages/ctc
git_branch: RELEASE_3_23
git_last_commit: 23f03f4
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:50:03 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 04:38:57 UTC; unix
